package WordList::CryptoCurrency::Catalog::Safename;

our $DATE = '2018-01-16'; # DATE
our $VERSION = '20180116'; # VERSION

use WordList;
our @ISA = qw(WordList);

our %STATS = ("longest_word_len",31,"avg_word_len",8.72275862068966,"shortest_word_len",2,"num_words",1450,"num_words_contains_whitespace",0,"num_words_contains_nonword_chars",283,"num_words_contains_unicode",0); # STATS

1;
# ABSTRACT: List of cryptocurrency safenames (a.k.a. slugs)

=pod

=encoding UTF-8

=head1 NAME

WordList::CryptoCurrency::Catalog::Safename - List of cryptocurrency safenames (a.k.a. slugs)

=head1 VERSION

This document describes version 20180116 of WordList::CryptoCurrency::Catalog::Safename (from Perl distribution WordLists-CryptoCurrency-Catalog), released on 2018-01-16.

=head1 SYNOPSIS

 use WordList::CryptoCurrency::Catalog::Safename;

 my $wl = WordList::CryptoCurrency::Catalog::Safename->new;

 # Pick a (or several) random word(s) from the list
 my $word = $wl->pick;
 my @words = $wl->pick(3);

 # Check if a word exists in the list
 if ($wl->word_exists('foo')) { ... }

 # Call a callback for each word
 $wl->each_word(sub { my $word = shift; ... });

 # Get all the words
 my @all_words = $wl->all_words;

=head1 STATISTICS

 +----------------------------------+------------------+
 | key                              | value            |
 +----------------------------------+------------------+
 | avg_word_len                     | 8.72275862068966 |
 | longest_word_len                 | 31               |
 | num_words                        | 1450             |
 | num_words_contains_nonword_chars | 283              |
 | num_words_contains_unicode       | 0                |
 | num_words_contains_whitespace    | 0                |
 | shortest_word_len                | 2                |
 +----------------------------------+------------------+

The statistics is available in the C<%STATS> package variable.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordLists-CryptoCurrency-Catalog>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordLists-CryptoCurrency-Catalog>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordLists-CryptoCurrency-Catalog>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

__DATA__
0x
10mtoken
1337coin
2give
300-token
42-coin
808coin
8bit
9coin
abjcoin
abncoin
accelerator-network
ace
aces
achain
acoin
adcoin
adelphoi
adshares
adtoken
advanced-internet-blocks
adx-net
adzcoin
aelf
aeon
aerium
aeron
aeternity
agoras-tokens
agrello-delta
agrolifecoin
aichain
aidoc
aidos-kuneen
aigang
aion
airswap
airtoken
akuya-coin
alis
allion
allsafe
alpacoin
alphabitcoinfund
alqo
altcoin-alt
altcommunity-coin
amber
ambercoin
ammo-rewards
amsterdamcoin
anarchistsprime
animecoin
anoncoin
anryze
antibitcoin
antilitecoin
antimatter
appcoins
applecoin-apw
apx
aquariuscoin
aragon
arbit
arcade-token
arcticcoin
ardor
argentum
argus
aricoin
ark
artbyte
artex-coin
asch
aseancoin
asiacoin
asiadigicoin
astro
atbcoin
atlant
atmcoin
atmos
atn
atomic-coin
attention-token-of-media
audiocoin
augur
auroracoin
aurumcoin
authorship
autonio
avatarcoin
aventus
avoncoin
aware
axiom
b2bx
b3coin
bancor
bankcoin
bankex
basic-attention-token
bastonet
bata
batcoin
bcap
bean-cash
beatcoin
beavercoin
belacoin
benjirolls
berncash
bestchain
betacoin
biblepay
bibox-token
bigone-token
bigup
billarycoin
billionaire-token
binance-coin
biobar
bios-crypto
bipcoin
birds
bismuth
bit20
bitair
bitalphacoin
bitasean
bitbar
bitbase
bitbay
bitboost
bitbtc
bitcedi
bitclave
bitcloud
bitcny
bitcoal
bitcoin
bitcoin-21
bitcoin-atom
bitcoin-cash
bitcoin-diamond
bitcoin-god
bitcoin-gold
bitcoin-planet
bitcoin-plus
bitcoin-red
bitcoin-scrypt
bitcoin-silver
bitcoin2x
bitcoindark
bitcoinfast
bitcoinx
bitcoinz
bitconnect
bitcore
bitcrystals
bitcurrency
bitdeal
bitdegree
bitdice
biteur
bitfid
bitgem
bitgold
bitmark
bitok
bitpark-coin
bitquark
bitqy
bitradio
bitsend
bitserial
bitshares
bitsilver
bitsoar
bitstar
bitswift
bittokens
bitusd
bitvolt
bitz
bitzeny
blackcoin
blackmoon-crypto
blackstar
blakecoin
blakestar
blazecoin
blazercoin
blitzcash
blockcat
blockcdn
blockchain-index
blockmason
blocknet
blockpay
blockpool
blocktix
blockv
bloomtoken
bluecoin
bnrtxcoin
bodhi
bolenum
bolivarcoin
bonpay
boolberry
boostcoin
boscoin
bottos
bounty0x
bowhead
bowscoin
braincoin
brat
bread
breakout
breakout-stake
briacoin
bridgecoin
britcoin
bt1-cst
bt2-cst
btcmoon
btctalkcoin
btsr
bubble
bulwark
bumbacoin
bunnycoin
burst
burstocean
buzzcoin
byteball
bytecent
bytecoin-bcn
bytom
c-bit
cabbage
cachecoin
californium
caliphcoin
campuscoin
canada-ecoin
cannabiscoin
cannacoin
cannation
canyacoin
cappasity
capricoin
carboncoin
cardano
cartaxi-token
cash-poker-pro
cashcoin
cashme
casino
catcoin
cbd-crystals
ccminer
ccore
centra
centurion
cfun
chaincoin
chainlink
chancoin
change
cheapcoin
chesscoin
chips
chronobank
chronologic
chronos
cindicator
circuits-of-value
civic
clams
clearpoll
cloakcoin
cloud
clubcoin
cobinhood
coexistcoin
coffeecoin
cofound-it
coimatic-2
coimatic-3
coin
coin2-1
coindash
coinlancer
coinonat
coinonatx
colossuscoin-v2
colossuscoinxt
comet
commodity-ad-network
compcoin
compucoin
comsa-eth
comsa-xem
concoin
condensate
confido
content-and-ad-network
copico
corethum
corgicoin
corion
coss
counterparty
coupecoin
crave
cream
creatio
creativecoin
credence-coin
creditbit
credo
crevacoin
crowdcoin
crown
crtcoin
cryptcoin
crypto
cryptocarbon
cryptoescudo
cryptoforecast
cryptogenic-bullion
cryptojacks
cryptonex
cryptonite
cryptopay
cryptopiafeeshares
cryptoping
cryptoworldx-token
crystal-clear
cthulhu-offerings
cubits
curecoin
cvcoin
cybcsec
cybercoin
cybermiles
cycling-coin
cyder
cypher
dai
dalecoin
dao-casino
dappster
darcrus
darklisk
darsek
dash
dashcoin
dashs
databits
datum
davorcoin
daxxcoin
dcorp
debitcoin
decent
decent-bet
decentraland
decision-token
decred
deepbrain-chain
deeponion
delphy
deltacredits
denarius-dnr
dent
dentacoin
desire
destiny
deuscoin
deutsche-emark
dew
dfscoin
diamond
dibcoin
digibyte
digicube
digipulse
digital-bullion-gold
digital-credits
digital-developers-fund
digital-money-bits
digital-rupees
digitalcoin
digitalnote
digitalprice
digixdao
dimcoin
dimecoin
dimoncoin
dinastycoin
district0x
divi
dix-asset
dnotes
dogecoin
dollar-online
dollarcoin
domraider
donationcoin
dopecoin
dotcoin
doubloon
dovu
draftcoin
dragonchain
dreamcoin
droxne
dubaicoin-dbix
dubstep
dutch-coin
dynamic
dynamic-trading-rights
dynamiccoin
e-coin
e-dinar-coin
e-gulden
ea-coin
eaglecoin
earthcoin
ebit
ebitcoin-cash
ebittree-coin
eboostcoin
ebtcnew
eccoin
echolink
ecobit
ecocoin
edgeless
edrcoin
eggcoin
ego
egold
eidoo
einsteinium
elacoin
elastic
elcoin-el
electra
electroneum
elementrem
elixir
ellaism
eltc
eltcoin
elysium
embers
emerald
emercoin
emphy
encrypgen
encryptotel
encryptotel-eth
energo
energycoin
enigma
enigma-project
enjin-coin
entcash
eos
eot-token
equitrader
erc20
ereal
ergo
eroscoin
eryllium
escoro
espers
eternity
ethbet
ethbits
ether-for-the-rest-of-the-world
etherdelta-token
ethereum
ethereum-blue
ethereum-classic
ethereum-dark
ethereum-gold
ethereum-lite
ethereum-movie-venture
ethereumcash
etheriya
etheroll
etherparty
ethgas
ethlend
ethos
eurocoin
europecoin
eusd
eventchain
everex
evergreencoin
everus
evil-coin
evotion
exchange-union
exchangen
exclusivecoin
expanse
experience-points
exrnchain
faceblock
facecoin
factom
faircoin
fairgame
fantomcoin
fapcoin
farad
fargocoin
farstcoin
fastcoin
fazzcoin
feathercoin
fedoracoin
fidentiax
filecoin
fimkrypto
fincoin
firecoin
fireflycoin
first-bitcoin
first-bitcoin-capital
firstblood
firstcoin
flappycoin
flash
flavorcoin
flaxscript
flik
flixxo
florincoin
fluttercoin
flycoin
flypme
foldingcoin
fonziecoin
footy-cash
force
francs
franko
frankywillcoin
frazcoin
freicoin
fucktoken
fuelcoin
fujicoin
fujinto
funcoin
fundyourselfnow
funfair
futcoin
futurexe
fuzzballs
gaia
gambit
game
gamebet-coin
gamechain
gamecredits
gameleaguecoin
gameunits
ganjacoin
gapcoin
gas
gaycoin
gbcgoldcoin
gcoin
geertcoin
genaro-network
genesis-vision
genstake
geocoin
geysercoin
gifto
giga-watt-token
gimli
glasscoin
global-business-revolution
global-currency-reserve
global-jobcoin
global-tour-coin
globalboost-y
globalcoin
globaltoken
gnosis-gno
gobyte
gold-pressed-latinum
gold-reward-token
goldblocks
goldcoin
goldmaxcoin
goldpieces
goldreserve
goldunioncoin
golem-network-tokens
golfcoin
golos
golos-gold
goodomy
gpu-coin
granitecoin
grantcoin
greencoin
grid
gridcoin
grimcoin
groestlcoin
growers-international
guccionecoin
gulden
guncoin
guppy
guts-tickets
gxshares
hacken
hackspace-capital
halcyon
halloween-coin
happy-creator-coin
happycoin
harmonycoin-hmc
hawala-today
healthywormcoin
heat-ledger
hedge
helleniccoin
hellogold
hempcoin
hempcoin-hmp
herocoin
hexx
hicoin
high-gain
high-performance-blockchain
high-voltage
hitcoin
hive
hobonickels
hodl-bucks
hodlcoin
hollywoodcoin
homeblockcoin
honey
hshare
html-coin
htmlcoin
hubii-network
humaniq
huncoin
huntercoin
hush
hyper
hyper-pay
hyper-tv
hyperstake
i0coin
ibank
ibtc
ico-openledger
icobid
icoin
icon
iconic
iconomi
icos
idice
iethereum
ignis
ignition
impact
impulsecoin
incakoin
incent
independent-money-system
india-coin
indorse-token
infchain
infinitecoin
infinity-economics
infinity-pay
inflationcoin
influxcoin
ink
innova
inpay
ins-ecosystem
insanecoin-insn
intelligent-trading-tech
intensecoin
international-diamond
internet-node-token
internet-of-people
internet-of-things
internxt
interstellar-holdings
interzone
investdigital
investfeed
invisiblecoin
iocoin
ion
iostoken
iot-chain
iota
iquant
irishcoin
islacoin
iticoin
ixcoin
ixledger
janus
javascript-token
jetcoin
jewels
jin-coin
jingtum-tech
jinn
jobscoin
joincoin
joulecoin
karbowanec
karma
karmacoin
kashhcoin
kayicoin
kcash
kekcoin
kemcredit
kickico
kilocoin
kin
kingn-coin
kobocoin
kolion
komodo
korecoin
kronecoin
kubera-coin
kucoin-shares
kurrent
kushcoin
kyber-network
kzcash
lamden
lampix
lanacoin
landcoin
lathaan
latoken
lazaruscoin
leacoin
leekico
legends-room
lendconnect
leocoin
lepen
letitride
leverj
leviarcoin
levoplus
lex4all
library-credit
life
lightning-bitcoin
linda
link-platform
linkedcoin
linx
lisk
litebar
litebitcoin
litecoin
litecoin-gold
litecoin-plus
litecoin-ultra
litecred
litedoge
lltoken
lockchain
lomocoin
loopring
lottocoin
luckchain
luna-coin
lunyr
luxcoin
lykke
machinecoin
macro1
macron
madcoin
maecenas
magi
magiccoin
magnet
magnetcoin
magnum
maidsafecoin
maker
mao-zedong
marijuanacoin
marscoin
martexcoin
marxcoin
master-swiscoin
masternodecoin
matryx
mavro
maxcoin
mazacoin
mcap
measurable-data-token
medibloc
medishares
megacoin
melon
memetic
mercury
mercury-protocol
mergecoin
metal
metal-music-coin
metalcoin
metaverse
micromoney
milocoin
mincoin
mindcoin
minereum
miners-reward-token
mineum
minex
minexcoin
mintcoin
mixin
mmxvi
moac
mobilecash
mobilego
modum
moeda-loyalty-points
moin
mojocoin
monaco
monacocoin
monacoin
monero
moneta2
monetaryunit
monetha
money
moneycoin
monkey-project
monster-byte
mooncoin
morningstar-payments
mothership
motocoin
msd
mtmgaming
musicoin
musiconomi
mustangcoin
mutual-coin
mybit-token
myriad
mysterium
mywish
naga
namecoin
namocoin
natcoin
nav-coin
neblio
nebulas-token
nekonium
nem
neo
neo-gold
neoscoin
netbit
netcoin
netko
network-token
neumark
neuro
neutron
nevacoin
neverdie
newbium
newyorkcoin
nexium
nexus
nimfamoney
nimiq
noblecoin
nodecoin
nolimitcoin
novacoin
nubits
nuls
numeraire
numus
numuscash
nushares
nvo
nxt
nyancoin
oax
obits
obsidian
oceanlab
ocow
octanox
octocoin
okcash
olympus-labs
omicron
omisego
omni
oneroot-network
ongsocial
onix
op-coin
opal
open-trading-network
operand
opescoin
opus
oraclechain
orbitcoin
orlycoin
ormeus-coin
osmiumcoin
ox-fina
oxycoin
oyster-pearl
p7coin
pabyosi-coin-special
paccoin
pakcoin
pandacoin-pnd
paragon
parallelcoin
parkbyte
particl
pascal-coin
pascal-lite
patientory
paycoin2
paycon
payfair
paypeer
paypex
paypie
peacecoin
peepcoin
peercoin
peerplays-ppy
peoplecoin
pepe-cash
pesetacoin
petrodollar
phantomx
philosopher-stones
phoenixcoin
phore
photon
piecoin
piggycoin
pillar
pinkcoin
pinkdog
pioneer-coin
piplcoin
pirate-blocks
pirl
pivx
pizzacoin
platinumbar
playercoin
playkey
plexcoin
plncoin
pluscoin
pluton
poet
pokecoin
polis
poly-ai
polybius
ponzicoin
popularcoin
populous
posex
postcoin
postoken
posw-coin
potcoin
power-ledger
prcoin
presearch
president-johnson
president-trump
primalbase
primas
prime-xi
primecoin
primulon
printerium
prismchain
privatix
prizm
prochain
procurrency
project-decorum
project-x
propy
prospectors-gold
protean
prototanium
psilocybin
publica
pulse
pura
pure
purevidz
putincoin
px
pylon-network
qash
qbao
qibuck-asset
qlink
qora
qtum
quantstamp
quantum
quantum-resistant-ledger
quark
quatloo
quazarcoin
qube
qubitcoin
quebecoin
qunqun
quotient
qvolta
qwark
rabbitcoin
radium
raiblocks
raiden-network-token
rasputin-online-coin
ratecoin
rawcoin2
rchain
rcoin
real
real-estate-tokens
rebellious
red-pulse
redcoin
reddcoin
reecoin
regacoin
regalcoin
remicoin
renos
request-network
revain
revolvercoin
rhfcoin
rialto
richcoin
ride-my-car
riecoin
rimbit
ripio-credit-network
ripple
ripto-bux
rise
rivetz
rlc
ronpaulcoin
roofs
roulettetoken
royal-kingdom-coin
royalcoin
royalties
rsgpcoin
rubies
rublebit
rubycoin
runners
rupaya
rupaya-old
rupee
russiacoin
russian-mining-coin
rustbits
sacoin
safe-exchange-coin
safe-trade-coin
safecoin
sagacoin
sakuracoin
salt
salus
sand-coin
santa-coin
santiment
sativacoin
satoshimadness
save-and-gain
scorecoin
secretcoin
securecoin
segwit2x
selfiecoin
selfkey
senderon
sequence
sexcoin
shacoin
shadow-token
shadowcash
sharechain
sharkcoin
shellcoin
shield-xsh
shift
shilling
shorty
show
siacoin
sibcoin
sigmacoin
signatum
simple-token
singulardtv
sirin-labs-token
sisa
sixeleven
skeincoin
skincoin
skycoin
slevin
sling
smart-investment-fund-token
smartbillions
smartcash
smartcoin
smartmesh
smileycoin
snakeeyes
snovio
soarcoin
social
social-send
socialcoin-socc
soilcoin
sojourn
solarcoin
solarflarecoin
solaris
soma
songcoin
sonm
sooncoin
sophiatx
sovereign-hero
spacecoin
spankchain
spectre-dividend
spectre-utility
spectrecoin
speedcash
sphere
sphre-air
sportscoin
sportyfi
spots
spreadcoin
sprouts
sproutsextreme
starbase
starcash-network
starcredits
starta
startcoin
status
stealthcoin
steem
steem-dollars
stellar
steneum-coin
steps
sterlingcoin
stex
storj
storjcoin-x
storm
stox
straks
stratis
streamr-datacoin
stress
strikebitclub
stronghands
student-coin
substratum
sugar-exchange
sumokoin
suncontract
super-bitcoin
supercoin
supernet-unity
suretly
swagbucks
swapcoin
swaptoken
swarm-city
swftcoin
swing
swisscoin
sydpak
syndicate
synereo
synergy
syscoin
t-coin
taas
tagcoin
tagrcoin
tajcoin
tao
target-coin
tattoocoin
tattoocoin-limited
teamup
techshares
tekcoin
telcoin
tellurion
tenx
teracoin
terracoin
terranova
teslacoilcoin
teslacoin
tether
tezos
the-champcoin
the-cypherfunks
the-vegan-initiative
thecreed
thegcccoin
theresa-may-coin
tierion
ties-network
tigercoin
time-new-bank
titcoin
tittiecoin
toacoin
todaycoin
tokencard
tokenclub
tokes
tokugawa
tokyo
topaz
topchain
topcoin
torcoin-tor
trackr
tracto
trade-token
transfercoin
trezarcoin
triaconta
triangles
trickycoin
trident
triggers
tristar-coin
trollcoin
tron
truckcoin
trueflip
trumpcoin
trust
trustplus
turbocoin
tychocoin
uahpay
ubiq
ufo-coin
ug-token
ugain
ugchain
ulatech
ultimate-secure-cash
ultracoin
unbreakablecoin
uncoin
unicoin
unify
unikoin-gold
united-bitcoin
unitus
unity-ingot
universal-currency
universalroyalcoin
universe
unobtanium
unrealcoin
upfiring
uquid-coin
ur
uro
usde
useless-ethereum-token
utacoin
utrust
uttoken
valorbit
vaperscoin
vault-coin
vcash
vechain
vector
veltor
verge
vericoin
verify
veritaseum
veriumreserve
veros
version
vertcoin
vezt
viacoin
vibe
viberate
vip-tokens
virta-unique-coin
virtacoin
virtacoinplus
virtualcoin
visio
viuly
vivo
voisecom
votecoin
voxels
voyacoin
vpncoin
vslice
vsync-vsx
vtorrent
vulcano
wa-space
wabi
wagerr
walton
wandx
warp
waves
waves-community-token
wavesgo
wax
wayguide
waykichain
wearesatoshi
weth
whalecoin
whitecoin
wi-coin
wild-beast-block
wild-crypto
win-coin
wings
wink
wmcoin
women
woodcoin
worldcoin
worldcore
wowcoin
x-coin
x2
xaucoin
xaurum
xde-ii
xenon
xgox
xios
xonecoin
xplay
xtd-coin
xtrabytes
xylo
yacoin
yashcoin
yellow-token
yenten
yescoin
yocoin
yoyow
zap
zayedcoin
zcash
zcash-gold
zclassic
zcoin
zeitcoin
zencash
zengold
zennies
zephyr
zero
zetacoin
zetamicron
zeusshield
zilbercoin
zoin
zonecoin
zozocoin
zrcoin
zsecoin
zurcoin
